@@ -2,16 +2,16 @@
  *                 Mathematical Object Library                 *
  *        Combinatorial Analysis Library - Include File        *
  *                    simula.plus@cemes.fr                     *
- *	             GNU/linux version 3.2.0                   *
+ *	             GNU/linux version 3.4.0                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright © 2004,2005,2006,2007,2008,2009,2012 COLLARD Christophe
- * copyright © 2004,2005,2006,2007,2008,2009,2012 Centre National de la Recherche Scientifique
+ * copyright © 2004,2005,2006,2007,2008,2009,2012,2018 COLLARD Christophe
+ * copyright © 2004,2005,2006,2007,2008,2009,2012,2018 Centre National de la Recherche Scientifique
  * copyright © 2004,2005,2006,2007,2008,2009 Arts et Métiers ParisTech
  * copyright © 2004,2005,2006,2007 Université de Valenciennes et du Hainaut Cambrésis
  * copyright © 2004,2005,2006,2007,2008,2009 Laboratoire de Physique et Mécanique des Matériaux (LPMM - CNRS)
  * copyright © 2004,2005,2006,2007 Laboratoire de Mathématiques et ses Applications de Valenciennes (LAMAV)
- * copyright © 2012 Centre d'Elaboration de Matériaux et d'Etudes Structurales (CEMES - CNRS)
+ * copyright © 2012,2018 Centre d'Elaboration de Matériaux et d'Etudes Structurales (CEMES - CNRS)
  ***************************************************************/
 
 /*! \namespace mol
@@ -44,15 +44,15 @@
     </FONT>
     \endhtmlonly
 
-    \author copyright \htmlonly &#169; \endhtmlonly 2004, 2005, 2006, 2007, 2008, 2009, 2012 Christophe COLLARD \n
-            copyright \htmlonly &#169; 2004, 2005, 2006, 2007, 2008, 2009, 2012 Centre National de la Recherche Scientifique \endhtmlonly \n
+    \author copyright \htmlonly &#169; \endhtmlonly 2004, 2005, 2006, 2007, 2008, 2009, 2012, 2018 Christophe COLLARD \n
+            copyright \htmlonly &#169; 2004, 2005, 2006, 2007, 2008, 2009, 2012, 2018 Centre National de la Recherche Scientifique \endhtmlonly \n
 	    copyright \htmlonly &#169; 2004, 2005, 2006, 2007, 2008, 2009 Arts et M&#233;tiers ParisTech \endhtmlonly \n
 	    copyright \htmlonly &#169; 2004, 2005, 2006, 2007 Universit&#233; de Valenciennes et du Hainaut Cambr&#233;sis \endhtmlonly \n
 	    copyright \htmlonly &#169; 2004, 2005, 2006, 2007, 2008, 2009 Laboratoire de Physique et M&#233;canique des Mat&#233;riaux (LPMM - CNRS) \endhtmlonly \n
 	    copyright \htmlonly &#169; 2004, 2005, 2006, 2007 Laboratoire de Math&#233;matiques et ses Applications de Valenciennes (LAMAV) \endhtmlonly \n
-	    copyright \htmlonly &#169; 2012 Centre d'Elaboration de Mat&#233;riaux et d'Etudes Structurales (CEMES - CNRS) \endhtmlonly \n
-    \version 3.2.0
-    \date 2004-2012
+	    copyright \htmlonly &#169; 2012, 2018 Centre d'Elaboration de Mat&#233;riaux et d'Etudes Structurales (CEMES - CNRS) \endhtmlonly \n
+    \version 3.4.0
+    \date 2004-2019
     \bug none
     \warning none
 */
@@ -113,8 +113,8 @@ template <class T> void combinatorial_analysis<T>::combinations
 //----------------------------------------------------------------------------------------------
 {
   for (int i=dim; i<=systems.dim(); i++)
-    { x[n] = systems[i];
-      if (n>1) combinations (n-1,systems,x,combinations_matrix,k,i+1);
+    { x[x.dim()-n+1] = systems[i];
+      if (n>1) combinations (n-1, systems, x, combinations_matrix, k, i+1);
       else combinations_matrix[k++] = x;
     }
 }
