@@ -2,17 +2,17 @@
  *                 Mathematical Object Library                 *
  *     class symmatrix:  declarations for symmetric matrix     *
  *                    simula.plus@cemes.fr                     *
- *                   GNU/linux version 3.2.0                   *
+ *                   GNU/linux version 3.4.0                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright © 2002,2003,2004,2005,2006,2007,2008,2009,2010,2012 COLLARD Christophe
+ * copyright © 2002,2003,2004,2005,2006,2007,2008,2009,2010,2012,2013 COLLARD Christophe
  * copyright © 2002,2003,2004 CREUSE Emmanuel
- * copyright © 2002,2003,2004,2005,2006,2007,2008,2009,2010,2012 Centre National de la Recherche Scientifique
+ * copyright © 2002,2003,2004,2005,2006,2007,2008,2009,2010,2012,2013 Centre National de la Recherche Scientifique
  * copyright © 2002,2003,2004,2005,2006,2007,2008,2009,2010 Arts et Métiers ParisTech
  * copyright © 2002,2003,2004,2005,2006,2007 Université de Valenciennes et du Hainaut Cambrésis
  * copyright © 2002,2003,2004,2005,2006,2007,2008,2009,2010 Laboratoire de Physique et Mécanique des Matériaux (LPMM - CNRS)
  * copyright © 2002,2003,2004,2005,2006,2007 Laboratoire de Mathématiques et ses Applications de Valenciennes (LAMAV)
- * copyright © 2010,2012 Centre d'Elaboration de Matériaux et d'Etudes Structurales (CEMES - CNRS)
+ * copyright © 2010,2012,2013 Centre d'Elaboration de Matériaux et d'Etudes Structurales (CEMES - CNRS)
  ***************************************************************/
 
 /*! \namespace mol
@@ -46,16 +46,16 @@
     \endhtmlonly
 
 
-    \authors copyright \htmlonly &#169; \endhtmlonly 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2012 Christophe COLLARD \n
+    \authors copyright \htmlonly &#169; \endhtmlonly 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2012, 2013 Christophe COLLARD \n
              copyright \htmlonly &#169; \endhtmlonly 2002, 2003, 2004 Emmanuel CREUSE \n
-             copyright \htmlonly &#169; 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2012 Centre National de la Recherche Scientifique \endhtmlonly \n
+             copyright \htmlonly &#169; 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2012, 2013 Centre National de la Recherche Scientifique \endhtmlonly \n
 	     copyright \htmlonly &#169; 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 Arts et M&#233;tiers ParisTech \endhtmlonly \n
 	     copyright \htmlonly &#169; 2002, 2003, 2004, 2005, 2006, 2007 Universit&#233; de Valenciennes et du Hainaut Cambr&#233;sis \endhtmlonly \n
 	     copyright \htmlonly &#169; 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010 Laboratoire de Physique et M&#233;canique des Mat&#233;riaux (LPMM - CNRS) \endhtmlonly \n
 	     copyright \htmlonly &#169; 2002, 2003, 2004, 2005, 2006, 2007 Laboratoire de Math&#233;matiques et ses Applications de Valenciennes (LAMAV) \endhtmlonly \n
-	     copyright \htmlonly &#169; 2010, 2012 Centre d'Elaboration de Mat&#233;riaux et d'Etudes Structurales (CEMES - CNRS) \endhtmlonly \n
-    \version 3.2.0
-    \date 2002-2012
+	     copyright \htmlonly &#169; 2010, 2012, 2013 Centre d'Elaboration de Mat&#233;riaux et d'Etudes Structurales (CEMES - CNRS) \endhtmlonly \n
+    \version 3.4.0
+    \date 2002-2019
     \bug none
     \warning none
 */
@@ -140,6 +140,7 @@ template <class T> class symmatrix : public virtual matrix<T>
     template <class Tf> friend symmatrix<Tf> gauss (const symmatrix<Tf>&);  // computes symmatrix inversion with gauss algorithm
     template <class Tf> friend symmatrix<Tf> abs (const symmatrix<Tf>&);    // returns the symmatrix absolute value
     T p_norm (int); // computes p-norm for matrix
+    symmatrix<T>& approximation ();
     template <class Tf> friend symmatrix<Tf> Id2s (int);                    // returns identity matrix
 };
 
@@ -565,6 +566,24 @@ template <class T> T symmatrix<T>::p_norm (int p)
 }
 
 
+//-------------------------------------------------------------
+template <class T> symmatrix<T>& symmatrix<T>::approximation ()
+//-------------------------------------------------------------
+{
+  assert (nbRows && nbColumns);
+
+  T elt;
+  T norm = sup (p_norm(2), (T) 1);
+
+  for (int i=1; i<=nbRows; i++)
+    for (int j=1; j<=i; j++)
+      if (abs (mrows[i-1][j]) < epsilon * norm)
+	mrows[i-1][j] = 0;
+
+  return *this;
+}
+
+
 //--------------------------------------------
 template <class Tf> symmatrix<Tf> Id2s (int n)
 //--------------------------------------------
