@@ -2,15 +2,15 @@
  *                 Mathematical Object Library                 *
  *class symtensor4: declaration for symmetric 4th order tensors*
  *                    simula.plus@cemes.fr                     *
- *	             GNU/linux version 3.2.0                   *
+ *	             GNU/linux version 3.4.0                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright © 2009,2010,2011,2012 COLLARD Christophe
- * copyright © 2009,2010,2011,2012 Centre National de la Recherche Scientifique
+ * copyright © 2009,2010,2011,2012,2017 COLLARD Christophe
+ * copyright © 2009,2010,2011,2012,2017 Centre National de la Recherche Scientifique
  * copyright © 2009,2010,2011 Arts et Métiers ParisTech
  * copyright © 2009,2010 Laboratoire de Physique et Mécanique des Matériaux (LPMM - CNRS)
  * copyright © 2011 Laboratoire d'Etude des Microstructures et de Mécanique des Matériaux (LEM3 - CNRS)
- * copyright © 2010,2011,2012 Centre d'Elaboration de Matériaux et d'Etudes Structurales (CEMES - CNRS)
+ * copyright © 2010,2011,2012,2017 Centre d'Elaboration de Matériaux et d'Etudes Structurales (CEMES - CNRS)
  ***************************************************************/
 
 /*! \namespace mol
@@ -46,14 +46,14 @@
     When fourth order tensors have the following symmetry properties \f$ T_{ijkl} = T_{jikl} = T_{ijlk} \f$, the storage and the operations on these tensors can be improved by using a matrix storage instead of the one given by the tensor4 class (sets of matrices). To do so, we associate with the tensor \f$ \boldsymbol{T} \f$ in \f$ \Bbb{R}^n \times \Bbb{R}^n \times \Bbb{R}^m \times \Bbb{R}^m \f$ the matrix \f$ \boldsymbol{M} \f$ in \f$ \Bbb{R}^{2n} \times \Bbb{R}^{2m} \f$ defined by: \n
 
 
-    \authors copyright \htmlonly &#169; \endhtmlonly 2009, 2010, 2011, 2012 Christophe COLLARD \n
-             copyright \htmlonly &#169; 2009, 2010, 2011, 2012 Centre National de la Recherche Scientifique \endhtmlonly \n
+    \authors copyright \htmlonly &#169; \endhtmlonly 2009, 2010, 2011, 2012, 2017 Christophe COLLARD \n
+             copyright \htmlonly &#169; 2009, 2010, 2011, 2012, 2017 Centre National de la Recherche Scientifique \endhtmlonly \n
 	     copyright \htmlonly &#169; 2009, 2010, 2011 Arts et M&#233;tiers ParisTech \endhtmlonly \n
 	     copyright \htmlonly &#169; 2009, 2010 Laboratoire de Physique et M&#233;canique des Mat&#233;riaux (LPMM - CNRS) \endhtmlonly \n
 	     copyright \htmlonly &#169; 2011 Laboratoire d'Etude des Microstructures et de M&#233;canique des Mat&#233;riaux (LEM3 - CNRS) \endhtmlonly \n
-	     copyright \htmlonly &#169; 2010, 2011, 2012 Centre d'Elaboration de Mat&#233;riaux et d'Etudes Structurales (CEMES - CNRS) \endhtmlonly \n
-    \version 3.2.0
-    \date 2009-2012
+	     copyright \htmlonly &#169; 2010, 2011, 2012, 2017 Centre d'Elaboration de Mat&#233;riaux et d'Etudes Structurales (CEMES - CNRS) \endhtmlonly \n
+    \version 3.4.0
+    \date 2009-2019
     \bug none
     \warning none
 */
@@ -1206,7 +1206,7 @@ template <class Tf> symtensor4<Tf> change_basis (const matrix<Tf>& P, const symt
 
   Tsr.mat = L * tsr.mat * t(L);
 
-  return Tsr;
+  return Tsr.approximation();
 }
 
 
