@@ -2,16 +2,16 @@
  *                 Mathematical Object Library                 *
  *      class tensor4 : declarations for 4th order tensors     *
  *                    simula.plus@cemes.fr                     *
- *                   GNU/linux version 3.2.0                   *
+ *                   GNU/linux version 3.4.0                   *
  *            software under General Public License            *
  ***************************************************************
- * copyright © 2004,2005,2006,2007,2008,2009,2010,2012 COLLARD Christophe
- * copyright © 2004,2005,2006,2007,2008,2009,2010,2012 Centre National de la Recherche Scientifique
+ * copyright © 2004,2005,2006,2007,2008,2009,2010,2012,2017 COLLARD Christophe
+ * copyright © 2004,2005,2006,2007,2008,2009,2010,2012,2017 Centre National de la Recherche Scientifique
  * copyright © 2004,2005,2006,2007,2008,2009,2010 Arts et Métiers ParisTech
  * copyright © 2004,2005,2006,2007 Université de Valenciennes et du Hainaut Cambrésis
  * copyright © 2004,2005,2006,2007,2008,2009,2010 Laboratoire de Physique et Mécanique des Matériaux (LPMM - CNRS)
  * copyright © 2004,2005,2006,2007 Laboratoire de Mathématiques et ses Applications de Valenciennes (LAMAV)
- * copyright © 2010,2012 Centre d'Elaboration de Matériaux et d'Etudes Structurales (CEMES - CNRS)
+ * copyright © 2010,2012,2017 Centre d'Elaboration de Matériaux et d'Etudes Structurales (CEMES - CNRS)
  ***************************************************************/
 
 /*! \namespace mol
@@ -44,15 +44,15 @@
     </FONT>
     \endhtmlonly
 
-    \author copyright \htmlonly &#169; \endhtmlonly 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2012 Christophe COLLARD \n
-            copyright \htmlonly &#169; 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2012 Centre National de la Recherche Scientifique \endhtmlonly \n
+    \author copyright \htmlonly &#169; \endhtmlonly 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2012, 2017 Christophe COLLARD \n
+            copyright \htmlonly &#169; 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2012, 2017 Centre National de la Recherche Scientifique \endhtmlonly \n
 	    copyright \htmlonly &#169; 2004, 2005, 2006, 2007, 2008, 2009, 2010 Arts et M&#233;tiers ParisTech \endhtmlonly \n
 	    copyright \htmlonly &#169; 2004, 2005, 2006, 2007 Universit&#233; de Valenciennes et du Hainaut Cambr&#233;sis \endhtmlonly \n
 	    copyright \htmlonly &#169; 2004, 2005, 2006, 2007, 2008, 2009, 2010 Laboratoire de Physique et M&#233;canique des Mat&#233;riaux (LPMM - CNRS) \endhtmlonly \n
 	    copyright \htmlonly &#169; 2004, 2005, 2006, 2007 Laboratoire de Math&#233;matiques et ses Applications de Valenciennes (LAMAV) \endhtmlonly \n
-	    copyright \htmlonly &#169; 2010, 2012 Centre d'Elaboration de Mat&#233;riaux et d'Etudes Structurales (CEMES - CNRS) \endhtmlonly \n
-    \version 3.2.0
-    \date 2004-2012
+	    copyright \htmlonly &#169; 2010, 2012, 2017 Centre d'Elaboration de Mat&#233;riaux et d'Etudes Structurales (CEMES - CNRS) \endhtmlonly \n
+    \version 3.4.0
+    \date 2004-2019
     \bug none
     \warning none
 */
@@ -1135,7 +1135,7 @@ template <class Tf> tensor4<Tf> change_basis (const matrix<Tf>& P, const tensor4
 		for (int l=1; l<=3; l++)
 		  Tsr(p,q,m,n) += P(p,i) * P(q,j) * P(m,k) * P(n,l) * tsr(i,j,k,l);
 
-  return Tsr;
+  return Tsr.approximation();
 }
 
 
